import pandas as pd
import matplotlib.pyplot as plt
import sys

with open(sys.argv[2], 'r') as data:
    data = pd.read_csv(data)

#Separating by Instances
instance1 = data.loc[data.instance == 'instance-1']
instance2 = data.loc[data.instance == 'instance-2']
instance3 = data.loc[data.instance == 'instance-3']

algos1 = instance1.groupby(['algorithm'])
epsilon1 = instance1.groupby(['epsilon'])
algos2 = instance2.groupby(['algorithm'])
epsilon2 = instance2.groupby(['epsilon'])
algos3 = instance3.groupby(['algorithm'])
epsilon3 = instance3.groupby(['epsilon'])

#Separating algorithm values for instance-1

rr1 = algos1.get_group('round-robin')
ucb1 = algos1.get_group('ucb')
klucb1 = algos1.get_group('kl-ucb')
thompson1 = algos1.get_group('thompson-sampling')
egreedy11 = epsilon1.get_group(0.002)
egreedy12 = epsilon1.get_group(0.02)
egreedy13 = epsilon1.get_group(0.2)

#Separating algorithm values for instance-2

rr2 = algos2.get_group('round-robin')
ucb2 = algos2.get_group('ucb')
klucb2 = algos2.get_group('kl-ucb')
thompson2 = algos2.get_group('thompson-sampling')
egreedy21 = epsilon2.get_group(0.002)
egreedy22 = epsilon2.get_group(0.02)
egreedy23 = epsilon2.get_group(0.2)

#Separating algorithm values for instance-3

rr3 = algos3.get_group('round-robin')
ucb3 = algos3.get_group('ucb')
klucb3 = algos3.get_group('kl-ucb')
thompson3 = algos3.get_group('thompson-sampling')
egreedy31 = epsilon3.get_group(0.002)
egreedy32 = epsilon3.get_group(0.02)
egreedy33 = epsilon3.get_group(0.2)

#Getting Horizon values for X-Axis for instance-1

rr_horizon1 = rr1.groupby("horizon")
ucb_horizon1 = ucb1.groupby('horizon')
klucb_horizon1 = klucb1.groupby('horizon')
thompson_horizon1 = thompson1.groupby('horizon')
egreedy11_horizon1 = egreedy11.groupby('horizon')
egreedy12_horizon1 = egreedy12.groupby('horizon')
egreedy13_horizon1 = egreedy13.groupby('horizon')

#Getting Horizon values for X-Axis for instance-2

rr_horizon2 = rr2.groupby("horizon")
ucb_horizon2 = ucb2.groupby('horizon')
klucb_horizon2 = klucb2.groupby('horizon')
thompson_horizon2 = thompson2.groupby('horizon')
egreedy21_horizon2 = egreedy21.groupby('horizon')
egreedy22_horizon2 = egreedy22.groupby('horizon')
egreedy23_horizon2 = egreedy23.groupby('horizon')

#Getting Horizon values for X-Axis for instance-3

rr_horizon3 = rr3.groupby("horizon")
ucb_horizon3 = ucb3.groupby('horizon')
klucb_horizon3 = klucb3.groupby('horizon')
thompson_horizon3 = thompson3.groupby('horizon')
egreedy31_horizon3 = egreedy31.groupby('horizon')
egreedy32_horizon3 = egreedy32.groupby('horizon')
egreedy33_horizon3 = egreedy33.groupby('horizon')


#Getting Mean(Regret) for Y-Axis for instance-1

rr_mean1 = rr_horizon1.regret.mean()
ucb_mean1 = ucb_horizon1.regret.mean()
klucb_mean1 = klucb_horizon1.regret.mean()
thompson_mean1 = thompson_horizon1.regret.mean()
egreedy11_mean1 = egreedy11_horizon1.regret.mean()
egreedy12_mean1 = egreedy12_horizon1.regret.mean()
egreedy13_mean1 = egreedy13_horizon1.regret.mean()

#Getting Mean(Regret) for Y-Axis for instance-2

rr_mean2 = rr_horizon2.regret.mean()
ucb_mean2 = ucb_horizon2.regret.mean()
klucb_mean2 = klucb_horizon2.regret.mean()
thompson_mean2 = thompson_horizon2.regret.mean()
egreedy21_mean2 = egreedy21_horizon2.regret.mean()
egreedy22_mean2 = egreedy22_horizon2.regret.mean()
egreedy23_mean2 = egreedy23_horizon2.regret.mean()

#Getting Mean(Regret) for Y-Axis for instance-3

rr_mean3 = rr_horizon3.regret.mean()
ucb_mean3 = ucb_horizon3.regret.mean()
klucb_mean3 = klucb_horizon3.regret.mean()
thompson_mean3 = thompson_horizon3.regret.mean()
egreedy31_mean3 = egreedy31_horizon3.regret.mean()
egreedy32_mean3 = egreedy32_horizon3.regret.mean()
egreedy33_mean3 = egreedy33_horizon3.regret.mean()

#Plot for Instance-1

fig = plt.figure(figsize=(12,8))

rr_mean1.plot(loglog = True, label = 'round-robin')
ucb_mean1.plot(loglog = True, label = 'ucb')
klucb_mean1.plot(loglog = True, label = 'kl-ucb')
thompson_mean1.plot(loglog = True, label = 'thompson-sampling')
egreedy11_mean1.plot(loglog = True, label = 'epsilon-greedy(0.002)')
egreedy12_mean1.plot(loglog = True, label = 'epsilon-greedy(0.02)')
egreedy13_mean1.plot(loglog = True, label = 'epsilon-greedy(0.2)')
plt.xlabel("horizon", fontsize = 11)
plt.ylabel("regret", fontsize = 11)
plt.title("Instance-1 Plot", fontsize = 16)
plt.legend(fontsize = 13)
plt.show()
fig.savefig('instance1.png', bbox_inches='tight')
plt.close()

#Plot for Instance-2

fig = plt.figure(figsize=(12,8))
rr_mean2.plot(loglog = True, label = 'round-robin')
ucb_mean2.plot(loglog = True, label = 'ucb')
klucb_mean2.plot(loglog = True, label = 'kl-ucb')
thompson_mean2.plot(loglog = True, label = 'thompson-sampling')
egreedy21_mean2.plot(loglog = True, label = 'epsilon-greedy(0.002)')
egreedy22_mean2.plot(loglog = True, label = 'epsilon-greedy(0.02)')
egreedy23_mean2.plot(loglog = True, label = 'epsilon-greedy(0.2)')
plt.xlabel("horizon", fontsize = 11)
plt.ylabel("regret", fontsize = 11)
plt.title("Instance-2 Plot", fontsize = 16)
plt.legend(fontsize = 13)
plt.show()
fig.savefig('instance2.png', bbox_inches='tight')
plt.close()

#Plot for Instance-3

fig = plt.figure(figsize=(12,8))
rr_mean3.plot(loglog = True, label = 'round-robin')
ucb_mean3.plot(loglog = True, label = 'ucb')
klucb_mean3.plot(loglog = True, label = 'kl-ucb')
thompson_mean3.plot(loglog = True, label = 'thompson-sampling')
egreedy31_mean3.plot(loglog = True, label = 'epsilon-greedy(0.002)')
egreedy32_mean3.plot(loglog = True, label = 'epsilon-greedy(0.02)')
egreedy33_mean3.plot(loglog = True, label = 'epsilon-greedy(0.2)')
plt.xlabel("horizon", fontsize = 11)
plt.ylabel("regret", fontsize = 11)
plt.title("Instance-3 Plot", fontsize = 16)
plt.legend(fontsize = 13)
plt.show()
fig.savefig('instance3.png', bbox_inches='tight')
plt.close()
